@@ -26,15 +26,14 @@ OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
-from __future__ import annotations
-
 import base64
 import logging
 import os
 import socket
 import time
+from collections.abc import Callable
 from itertools import cycle, islice
-from typing import Any, Callable, Optional, Tuple
+from typing import Any
 
 from aiohttp import (
     ClientResponseError,
@@ -49,7 +48,7 @@ from .colours import TwinklyColour, TwinklyColourTuple
 _LOGGER = logging.getLogger(__name__)
 
 TwinklyFrame = list[TwinklyColourTuple]
-TwinklyResult = Optional[dict]
+TwinklyResult = dict | None
 
 
 TWINKLY_MODES = [
@@ -214,9 +213,10 @@ class Twinkly:
         self._api_version = None
         return None
 
-    async def _post(self, endpoint: str, **kwargs) -> Any:
+    async def _post(self, endpoint: str, require_token: bool = True, **kwargs) -> Any:
         await self.get_api_version()
-        await self.ensure_token()
+        if require_token:
+            await self.ensure_token()
         _LOGGER.debug("POST endpoint %s", endpoint)
         if "json" in kwargs:
             _LOGGER.debug("POST payload %s", kwargs["json"])
@@ -238,9 +238,10 @@ class Twinkly:
             else:
                 raise e
 
-    async def _get(self, endpoint: str, **kwargs) -> Any:
+    async def _get(self, endpoint: str, require_token: bool = True, **kwargs) -> Any:
         await self.get_api_version()
-        await self.ensure_token()
+        if require_token:
+            await self.ensure_token()
         _LOGGER.debug("GET endpoint %s", endpoint)
         headers = kwargs.pop("headers", self._headers)
         retry_num = kwargs.pop("retry_num", 0)
@@ -335,7 +336,7 @@ class Twinkly:
         return self._valid_response(await self._get(endpoint))
 
     async def get_details(self) -> Any:
-        return self._valid_response(await self._get("gestalt"))
+        return self._valid_response(await self._get("gestalt", require_token=False))
 
     async def is_on(self) -> bool | None:
         mode = await self.get_mode()
@@ -419,7 +420,7 @@ class Twinkly:
             await self.interview()
         if isinstance(colour, list):
             colour = colour[0]
-        if isinstance(colour, Tuple):
+        if isinstance(colour, tuple):
             colour = TwinklyColour.from_twinkly_tuple(colour)
         if await self.get_api_version() == 1:
             await self._post(
@@ -440,7 +441,7 @@ class Twinkly:
     ) -> None:
         if isinstance(colour, TwinklyColour):
             sequence = [colour.as_twinkly_tuple()]
-        elif isinstance(colour, Tuple):
+        elif isinstance(colour, tuple):
             sequence = [colour]
         elif isinstance(colour, list):
             sequence = [c.as_twinkly_tuple() for c in colour] if isinstance(colour[0], TwinklyColour) else colour
